@@ -7,6 +7,7 @@ local guide          = require 'parser.guide'
 local converter      = require 'proto.converter'
 local config         = require 'config'
 local linkedTable    = require 'linked-table'
+local client         = require 'client'
 
 local Care = util.switch()
     : case 'getglobal'
@@ -32,10 +33,10 @@ local Care = util.switch()
             end
             options.libGlobals[name] = isLib
         end
-        local isFunc = vm.getInfer(source):hasFunction()
+        local isFunc = vm.getInfer(source):hasFunction(guide.getUri(source))
 
         local type = isFunc and define.TokenTypes['function'] or define.TokenTypes.variable
-        local modifier = isLib and define.TokenModifiers.defaultLibrary or define.TokenModifiers.static
+        local modifier = isLib and define.TokenModifiers.defaultLibrary or define.TokenModifiers.global
 
         results[#results+1] = {
             start      = source.start,
@@ -65,28 +66,30 @@ local Care = util.switch()
         if not options.variable then
             return
         end
-        local modifiers = 0
-        if source.parent and source.parent.type == 'tablefield' then
-            modifiers = define.TokenModifiers.declaration
-        end
         if source.parent then
+            if source.parent.type == 'tablefield' then
+                results[#results+1] = {
+                    start      = source.start,
+                    finish     = source.finish,
+                    type       = define.TokenTypes.property,
+                }
+                return
+            end
             local value = source.parent.value
             if value and value.type == 'function' then
                 results[#results+1] = {
                     start      = source.start,
                     finish     = source.finish,
                     type       = define.TokenTypes.method,
-                    modifieres = modifiers,
                 }
                 return
             end
         end
-        if vm.getInfer(source):hasFunction() then
+        if vm.getInfer(source):hasFunction(guide.getUri(source)) then
             results[#results+1] = {
                 start      = source.start,
                 finish     = source.finish,
                 type       = define.TokenTypes.method,
-                modifieres = modifiers,
             }
             return
         end
@@ -95,7 +98,6 @@ local Care = util.switch()
                 start      = source.start,
                 finish     = source.finish,
                 type       = define.TokenTypes.method,
-                modifieres = modifiers,
             }
             return
         end
@@ -103,7 +105,6 @@ local Care = util.switch()
             start      = source.start,
             finish     = source.finish,
             type       = define.TokenTypes.property,
-            modifieres = modifiers,
         }
     end)
     : case 'local'
@@ -134,19 +135,16 @@ local Care = util.switch()
             return
         end
         local loc = source.node or source
+        local uri = guide.getUri(loc)
         -- 1. 值为函数的局部变量 | Local variable whose value is a function
-        if loc.ref then
-            for _, ref in ipairs(loc.ref) do
-                if ref.value and ref.value.type == 'function' then
-                    results[#results+1] = {
-                        start      = source.start,
-                        finish     = source.finish,
-                        type       = define.TokenTypes['function'],
-                        modifieres = define.TokenModifiers.declaration,
-                    }
-                    return
-                end
-            end
+        if vm.getInfer(source):hasFunction(uri) then
+            results[#results+1] = {
+                start      = source.start,
+                finish     = source.finish,
+                type       = define.TokenTypes['function'],
+                modifieres = define.TokenModifiers.declaration,
+            }
+            return
         end
         -- 3. 特殊变量 | Special variableif source[1] == '_ENV' then
         if loc[1] == '_ENV' then
@@ -196,12 +194,12 @@ local Care = util.switch()
             end
         end
         -- 6. References to other functions
-        if vm.getInfer(loc):hasFunction() then
+        if vm.getInfer(loc):hasFunction(guide.getUri(source)) then
             results[#results+1] = {
                 start      = source.start,
                 finish     = source.finish,
                 type       = define.TokenTypes['function'],
-                modifieres = guide.isSet(source) and define.TokenModifiers.declaration or nil,
+                modifieres = guide.isAssign(source) and define.TokenModifiers.declaration or nil,
             }
             return
         end
@@ -440,6 +438,13 @@ local Care = util.switch()
                 type       = define.TokenTypes.type,
                 modifieres = define.TokenModifiers.modification,
             }
+        elseif source[1] == 'self' then
+            results[#results+1] = {
+                start      = source.start,
+                finish     = source.finish,
+                type       = define.TokenTypes.type,
+                modifieres = define.TokenModifiers.readonly,
+            }
         else
             results[#results+1] = {
                 start  = source.start,
@@ -449,6 +454,7 @@ local Care = util.switch()
         end
     end)
     : case 'doc.alias.name'
+    : case 'doc.enum.name'
     : call(function (source, options, results)
         if not options.annotation then
             return
@@ -594,17 +600,6 @@ local Care = util.switch()
             type       = define.TokenTypes.class,
         }
     end)
-    : case 'doc.see.field'
-    : call(function (source, options, results)
-        if not options.annotation then
-            return
-        end
-        results[#results+1] = {
-            start      = source.start,
-            finish     = source.finish,
-            type       = define.TokenTypes.property,
-        }
-    end)
     : case 'doc.diagnostic'
     : call(function (source, options, results)
         if not options.annotation then
@@ -667,6 +662,14 @@ local Care = util.switch()
             type   = define.TokenTypes.keyword,
         }
     end)
+    : case 'doc.cast.block'
+    : call(function (source, options, results)
+        results[#results+1] = {
+            start      = source.start,
+            finish     = source.finish,
+            type       = define.TokenTypes.keyword,
+        }
+    end)
     : case 'doc.cast.name'
     : call(function (source, options, results)
         results[#results+1] = {
@@ -675,14 +678,41 @@ local Care = util.switch()
             type       = define.TokenTypes.variable,
         }
     end)
+    : case 'doc.type.code'
+    : call(function (source, options, results)
+        results[#results+1] = {
+            start      = source.start,
+            finish     = source.finish,
+            type       = define.TokenTypes.string,
+            modifieres = define.TokenModifiers.abstract,
+        }
+    end)
+    : case 'doc.operator.name'
+    : call(function (source, options, results)
+        results[#results+1] = {
+            start      = source.start,
+            finish     = source.finish,
+            type       = define.TokenTypes.operator,
+        }
+    end)
+    : case 'doc.meta.name'
+    : call(function (source, options, results)
+        results[#results+1] = {
+            start      = source.start,
+            finish     = source.finish,
+            type       = define.TokenTypes.namespace,
+        }
+    end)
 
-local function buildTokens(uri, results)
+---@param state table
+---@param results table
+local function buildTokens(state, results)
     local tokens = {}
     local lastLine = 0
     local lastStartChar = 0
     for i, source in ipairs(results) do
-        local startPos  = converter.packPosition(uri, source.start)
-        local finishPos = converter.packPosition(uri, source.finish)
+        local startPos  = source.start
+        local finishPos = source.finish
         local line      = startPos.line
         local startChar = startPos.character
         local deltaLine = line - lastLine
@@ -763,23 +793,35 @@ local function solveMultilineAndOverlapping(state, results)
 
     local new = {}
     for token in tokens:pairs() do
-        new[#new+1] = token
-        local startRow,  startCol  = guide.rowColOf(token.start)
-        local finishRow, finishCol = guide.rowColOf(token.finish)
-        if finishRow > startRow then
-            token.finish = guide.positionOf(startRow, guide.getLineRange(state, startRow))
-            for i = startRow + 1, finishRow - 1 do
+        local startPos = converter.packPosition(state, token.start)
+        local endPos   = converter.packPosition(state, token.finish)
+        if endPos.line == startPos.line
+        or client.getAbility 'textDocument.semanticTokens.multilineTokenSupport' then
+            new[#new+1] = {
+                start      = startPos,
+                finish     = endPos,
+                type       = token.type,
+                modifieres = token.modifieres,
+            }
+        else
+            new[#new+1] = {
+                start      = startPos,
+                finish     = converter.position(startPos.line, 9999),
+                type       = token.type,
+                modifieres = token.modifieres,
+            }
+            for i = startPos.line + 1, endPos.line - 1 do
                 new[#new+1] = {
-                    start      = guide.positionOf(i, 0),
-                    finish     = guide.positionOf(i, guide.getLineRange(state, i)),
+                    start      = converter.position(i, 0),
+                    finish     = converter.position(i, 9999),
                     type       = token.type,
                     modifieres = token.modifieres,
                 }
             end
-            if finishCol > 0 then
+            if endPos.character > 0 then
                 new[#new+1] = {
-                    start      = guide.positionOf(finishRow, 0),
-                    finish     = guide.positionOf(finishRow, finishCol),
+                    start      = converter.position(endPos.line, 0),
+                    finish     = converter.position(endPos.line, endPos.character),
                     type       = token.type,
                     modifieres = token.modifieres,
                 }
@@ -792,12 +834,13 @@ end
 
 ---@async
 return function (uri, start, finish)
+    local results = {}
     if not config.get(uri, 'Lua.semantic.enable') then
-        return nil
+        return results
     end
     local state = files.getState(uri)
     if not state then
-        return nil
+        return results
     end
 
     local options = {
@@ -810,10 +853,13 @@ return function (uri, start, finish)
         keyword    = config.get(uri, 'Lua.semantic.keyword'),
     }
 
-    local results = {}
+    local n = 0
     guide.eachSourceBetween(state.ast, start, finish, function (source) ---@async
         Care(source.type, source, options, results)
-        await.delay()
+        n = n + 1
+        if n % 100 == 0 then
+            await.delay()
+        end
     end)
 
     for _, comm in ipairs(state.comms) do
@@ -849,12 +895,12 @@ return function (uri, start, finish)
     end
 
     if #results == 0 then
-        return {}
+        return results
     end
 
     results = solveMultilineAndOverlapping(state, results)
 
-    local tokens = buildTokens(uri, results)
+    local tokens = buildTokens(state, results)
 
     return tokens
 end
